import React, { Component } from 'react'
import { Route, Link, withRouter } from 'react-router-dom'
import {connect} from 'react-redux'
import './dashboard.scss'

import  Piechart from '../charts/Piechart/Piechart'
import  Barchart from '../charts/Piechart/Barchart'
import  NewPieChart from '../charts/Piechart/NewPieChart'
import  LineChart from '../charts/Piechart/LineChart'
import DashboardCharts from '../charts/DashboardCharts'
import MyLineChart from '../charts/LineChart'
//import D3PieChart from '../charts/D3PieChart'

import AdminMenu from '../AdminMenu/AdminMenu'
import AdminProfileMenu from '../AdminProfileMenu'

import  Logo from '../../Header/Logo'

import ProfilePage from '../Profile/ProfilePage'
import Toasts from '../../UI/Toasts/Toasts'
import Content from '../Content'
import UsersPage from '../Users'
import Comments from '../Comments'
import Clients from '../Clients'
import Settings from '../Settings'
import Sidebar from '../Sidebar'
import DashboardStats from './DashboardStats'
import NotificationContainer from '../Notifications/NotificationContainer'
import EditContentPage from '../Content/EditContentPage'
import ViewContent from '../Content/ViewContentPage'
import {toggleNotificationBar} from "../../../AC";
import {loadDashboardStats} from "../../../AC/adminActions";
import ClientChart from "../charts/ClientChart";

class Dashboard extends Component {
  state = {
    miniSidebar: false,
    sidebarBg: 'light'
  }
  toggleNotifications = () => {
    const { dispatch } = this.props
    this.props.toggleNotificationBar()
    console.log('diss')
  }

  toggleSidebar = () => {
    this.setState({
      miniSidebar: !this.state.miniSidebar
    })
  }

  setSidebarBg = (ev) => {
    if (ev.target.checked) {
      this.setState({
        sidebarBg: ev.target.value
      })
    } else {
      this.setState({
        sidebarBg: 'light'
      })
    }
  }

  componentDidMount() {
    this.props.loadDashboardStats()
  }

  render() {
    const { settings, currentUser, changeLanguage, clients, stats, miniSidebar } = this.props
    return (
        <div className="auth--layout-container">
          <header className="auth--header">
            <Link to="/" className={`auth--branding${this.state.miniSidebar ? ' minified' : ''}${this.state.sidebarBg === 'dark' ? ' dark-bg' : ''}`}>
              <Logo settings={settings} />
              {this.state.miniSidebar ? null : settings.site_name}
            </Link>
            <div className="auth--navbar">
            <AdminMenu toggleSidebar={this.toggleSidebar} />
            <AdminProfileMenu
                settings={settings}
                user={currentUser}
                notificationBar={settings.showNotificationBar}
                toggleNotifications={this.toggleNotifications}
                language={settings.language}
                changeLanguage={changeLanguage}
            />
            </div>
          </header>
          <Sidebar
              settings={settings}
              minified={this.state.miniSidebar}
              sidebarBg={this.state.sidebarBg}
          />
          <div className={`auth--main-wrapper ${this.state.miniSidebar ? 'with-mini-sidebar' : ''}`}>

            <main className="auth--main">
              <DashboardStats dashboard={settings.dashboard}/>

              <Route exact path="/dashboard" render={() => <DashboardCharts />} />
              <Route path="/dashboard/content" component={Content}/>
              <Route path="/dashboard/users" render={() => <UsersPage userRoles={localStorage.getItem('user_roles')}/>}/>
              <Route path="/dashboard/comments" component={Comments}/>
              <Route path="/dashboard/clients" render={() => <Clients userRoles={localStorage.getItem('user_roles')}/>}/>
              <Route path="/dashboard/profile" component={ProfilePage}/>
              <Route path="/dashboard/settings" render={() => <Settings setSidebarBg={this.setSidebarBg} />}/>
            </main>
          </div>
          {settings.showNotificationBar ? <NotificationContainer/> : null }
          <Toasts/>
        </div>
    )
  }
}

export default withRouter(connect((store, props)  => ({
  settings: store.settings,
  //stats: store.settings.dashboard.dashboardStats,
  currentUser: store.currentUser,
  changeLanguage: props.changeLanguage,
  clients: store.clients

}), {loadDashboardStats, toggleNotificationBar})(Dashboard))